#!/usr/bin/env node
const path = require('path')
const { existsSync } = require('fs-extra')
const logger = require('./src/utils/logger')
const rollup = require('./src/rollup')
const createBoilerplate = require('./src/boilerplate')

// check config file
const conf = path.join(process.cwd(), 'clair.config.js')

if (!existsSync(conf)) {
  logger.error(
    'No such file called `clair.config.js` in' +
    'current working directory'
  )
  process.exit()
}

// try to require config file
let config = null
try {
  config = require(conf)
} catch (e) {
  logger.error(e)
  process.exit()
}

const argv = process.argv.slice(2)
switch (argv[0]) {
  case 'watch-build':
    process.env.NODE_ENV = 'development'
    rollup.watchBuild(config.rollup)
    break

  case 'build':
    process.env.NODE_ENV = 'production'
    Promise.resolve()
      .then(() => rollup.build(config.rollup))
      .catch(e => {
        logger.log(e)
        process.exit()
      })
    break

  case 'add':
    if (argv[1]) {
      const obj = Object.assign({
        name: argv[1],
        prefix: 'c',
        dir: 'src/components'
      }, config.boilerplate)

      createBoilerplate(obj)
    }
    break

  default:
}
