const path = require('path')
const fs = require('fs-extra')
const { kebabCase, pascalCase } = require('./utils/case')
const logger = require('./utils/logger')

module.exports = function ({
  name,
  dir = 'src/components',
  prefix = 'c',
  files = {}
}) {
  // eg: ButtonGroup => button-group
  const route = kebabCase(name)
  // eg: button-group => ButtonGroup
  const component = pascalCase(name)
  // c-button-group
  const tagName = (prefix ? prefix + '-' : '') + route

  const dest = path.join(dir, route)

  // check
  if (fs.existsSync(dest)) {
    logger.warn(
      `Skipping component ${component}` +
      `, it already exisits at ${dest}.`
    )
    return
  }

  return Object
    .keys(files)
    .reduce(
      (promise, filename) => {
        let content = files[filename]

        if (typeof content === 'function') {
          content = content({
            tagName,
            componentName: component,
            route
          })
        }

        const file = `${dest}/${filename}`

        return promise
          .then(() => fs.ensureFile(file))
          .then(() => fs.writeFile(file, content))
      },
      Promise.resolve()
    )
    .then(() => {
      logger.info(`Component ${component} is created at ${dest}.`)
    })
}
