const rollup = require('rollup')
const chokidar = require('chokidar')
const { ensureFileSync } = require('fs-extra')
const logger = require('./utils/logger')

exports.build = function ({ name, input, output, plugins }) {
  logger.log('Rollup', `release-build starts`)

  // returns a Promise
  return rollup.rollup({
    input,
    plugins
  })
  .then(bundle =>
    Promise.all(
      output.map(({ file, format }) => {
        ensureFileSync(file)
        return bundle.write({ name, file, format })
      })
    )
  )
  .then(ret => {
    logger.log('Rollup', 'release-build done')
    return ret
  })
  .catch(e => {
    logger.log(e)
  })
}

exports.watchBuild = function ({ name, input, output, plugins }) {
  logger.log('Rollup', 'watch-build starts')

  // https://rollupjs.org/#rollup-watch
  const watcher = rollup.watch({
    input,
    plugins,
    output: output.map(o => (o.name = name) && o),
    watch: { chokidar }
  })

  return new Promise((resolve, reject) => {
    watcher.on('event', function listener ({ code, error }) {
      if (error) {
        reject(error)
      }

      if (code === 'END') {
        logger.log('Rollup', 'build done')

        watcher.removeListener('event', listener)
        watcher.on('event', ({ code, err }) => {
          if (err) {
            logger.error(err)
          } else {
            logger.log('Rollup', code)
          }
        })
        resolve()
      }
    })
  })
}
